use tonic::{transport::Server, Request, Response, Status};

use self::shoebill::repo_server::{Repo, RepoServer};
use self::shoebill::Bundle;

pub mod shoebill {
    tonic::include_proto!("shoebill"); // The string specified here must match the proto package name
}

#[derive(Debug, Default)]
pub struct MyGreeter {}

#[tonic::async_trait]
impl Repo for MyGreeter {
    async fn download(
        &self,
        req: Request<Bundle>,
    ) -> Result<Response<Bundle>, Status> {
        Ok(Response::new(Bundle::default()))
    }
}

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    let addr = "[::1]:50051".parse()?;
    let greeter = MyGreeter::default();

    Server::builder()
        .add_service(RepoServer::new(greeter))
        .serve(addr)
        .await?;

    Ok(())
}